pub struct GeometryView<'a, VR: VertexRef, SS: StringStorage> { /* private fields */ }Expand description
A read view over a geometry, optionally resolved from a GeometryInstance.
When obtained from CityModel::resolve_geometry,
this view points at the effective geometry type (e.g. the MultiSurface that a
GeometryInstance references), with the original instance data available through
GeometryView::instance.
Implementations
Sourceimpl<'a, VR: VertexRef, SS: StringStorage> GeometryView<'a, VR, SS>
impl<'a, VR: VertexRef, SS: StringStorage> GeometryView<'a, VR, SS>
Methods from Deref<Target = Geometry<VR, SS>>
pub fn type_geometry(&self) -> &GeometryType
pub fn lod(&self) -> Option<&LoD>
pub fn boundaries(&self) -> Option<&Boundary<VR>>
pub fn coordinates<'a, V: Coordinate>( &'a self, vertices: &'a Vertices<VR, V>, ) -> Option<BoundaryCoordinates<'a, VR, V>>
pub fn unique_vertex_indices<'a>( &'a self, scratch: &'a mut Vec<VertexIndex<VR>>, ) -> Option<&'a [VertexIndex<VR>]>
pub fn unique_coordinates<'a, V: Coordinate>( &'a self, vertices: &'a Vertices<VR, V>, scratch: &'a mut Vec<VertexIndex<VR>>, ) -> Option<BoundaryUniqueCoordinates<'a, VR, V>>
pub fn semantics(&self) -> Option<SemanticMapView<'_, VR>>
pub fn materials(&self) -> Option<MaterialThemesView<'_, VR, SS>>
pub fn textures(&self) -> Option<TextureThemesView<'_, VR, SS>>
pub fn instance(&self) -> Option<GeometryInstanceView<'_, VR>>