pub type BoundaryNestedMultiLineString16 = Vec<BoundaryNestedMultiPoint16>;Expand description
A collection of linestrings for a model with 16-bit indices
Aliased Type
pub struct BoundaryNestedMultiLineString16 { /* private fields */ }pub type BoundaryNestedMultiLineString16 = Vec<BoundaryNestedMultiPoint16>;A collection of linestrings for a model with 16-bit indices
pub struct BoundaryNestedMultiLineString16 { /* private fields */ }