pub type BoundaryNestedMultiLineString32 = Vec<BoundaryNestedMultiPoint32>;Expand description
A collection of linestrings for a model with 32-bit indices
Aliased Type
pub struct BoundaryNestedMultiLineString32 { /* private fields */ }pub type BoundaryNestedMultiLineString32 = Vec<BoundaryNestedMultiPoint32>;A collection of linestrings for a model with 32-bit indices
pub struct BoundaryNestedMultiLineString32 { /* private fields */ }