pub type BoundaryNestedMultiLineString64 = Vec<BoundaryNestedMultiPoint64>;Expand description
A collection of linestrings for a model with 64-bit indices
Aliased Type
pub struct BoundaryNestedMultiLineString64 { /* private fields */ }pub type BoundaryNestedMultiLineString64 = Vec<BoundaryNestedMultiPoint64>;A collection of linestrings for a model with 64-bit indices
pub struct BoundaryNestedMultiLineString64 { /* private fields */ }