pub type BoundaryNestedSolid<T> = Vec<BoundaryNestedMultiOrCompositeSurface<T>>;Expand description
A solid represented as shells with generic index type
Aliased Type
pub struct BoundaryNestedSolid<T> { /* private fields */ }pub type BoundaryNestedSolid<T> = Vec<BoundaryNestedMultiOrCompositeSurface<T>>;A solid represented as shells with generic index type
pub struct BoundaryNestedSolid<T> { /* private fields */ }